@@ -80,7 +80,7 @@ de = "de"/Struct(
     "population_limit"/Int32ul,
     "num_players"/Int32ul,
     "unused_player_color"/Int32ul,
-    "victory_amount"/Int32ul,
+    "victory_amount"/Int32sl,
     separator,
     "trade_enabled"/Flag,
     "team_bonus_disabled"/Flag,
@@ -100,6 +100,7 @@ de = "de"/Struct(
     "sub_game_mode"/If(lambda ctx: find_save_version(ctx) >= 13.34, Int32ul),
     "battle_royale_time"/If(lambda ctx: find_save_version(ctx) >= 13.34, Int32ul),
     "handicap"/If(lambda ctx: find_save_version(ctx) >= 25.06, Flag),
+    "unk"/If(lambda ctx: find_save_version(ctx) >= 51, Flag),
     separator,
     "players"/Array(lambda ctx: ctx.num_players if find_save_version(ctx) >= 37 else 8, player),
     Bytes(9),
@@ -152,6 +153,7 @@ de = "de"/Struct(
     If(lambda ctx: find_save_version(ctx) >= 25.22, Bytes(4)),
     If(lambda ctx: find_save_version(ctx) >= 26.16, Bytes(8)),
     If(lambda ctx: find_save_version(ctx) >= 37, Bytes(3)),
+    If(lambda ctx: find_save_version(ctx) >= 51, Bytes(8)),
     de_string,
     Bytes(5),
     If(lambda ctx: find_save_version(ctx) >= 13.13, Byte),
