@@ -19,6 +19,21 @@ LOGGER = logging.getLogger(__name__)
 SEARCH_MAX_BYTES = 3000
 POSTGAME_LENGTH = 2096
 LOOKAHEAD = 9
+DE_MARKERS = {
+    38: b"\xa4\x70\xbd\x3f",
+    37: b"\xf6\x28\xbc\x3f",
+    26.21: b"\xf6\x28\xbc\x3f",
+    26.16: b"\x48\xe1\xba\x3f",
+    25.06: b"\x9a\x99\xb9\x3f",
+    25.03: b"\x85\xeb\x91\x3f",
+    25.02: b"\xec\x51\xb8\x3f",
+    25.01: b"\x3d\x0a\xb7\x3f",
+    20.16: b"\x8f\xc2\xb5\x3f",
+    20.06: b"\xe1\x7a\xb4\x3f",
+    13.34: b"\x33\x33\xb3\x3f",
+    13.07: b"\x29\x5c\xaf\x3f",
+    12.97: b"\x7b\x14\xae\x3f"
+}
 
 
 class Version(Enum):
@@ -256,6 +271,7 @@ class GotoObjectsEnd(Construct):
         num_players = context._._.replay.num_players
         marker_num = context.attributes.num_header_data
         save_version = context._._.save_version
+        version = find_version(context)
         start = stream.tell()
         # Have to read everything to be able to use find()
         read_bytes = stream.read()
@@ -278,44 +294,22 @@ class GotoObjectsEnd(Construct):
             marker_aok = read_bytes.find(b"\x9a\x99\x99\x3f")
             marker_up = read_bytes.find(b"\xf6\x28\x9c\x3f")
             marker_hd = read_bytes.find(b"\xae\x47\xa1\x3f")
-            if save_version >= 38:
-                marker_de = read_bytes.find(b"\xa4\x70\xbd\x3f")
-            elif save_version >= 37:
-                marker_de = read_bytes.find(b"\xf6\x28\xbc\x3f")
-            elif save_version >= 26.21:
-                marker_de = read_bytes.find(b"\xf6\x28\xbc\x3f")
-            elif save_version >= 26.16:
-                marker_de = read_bytes.find(b"\x48\xe1\xba\x3f")
-            elif save_version >= 25.06:
-                marker_de = read_bytes.find(b"\x9a\x99\xb9\x3f")
-            elif save_version >= 25.03:
-                marker_de = read_bytes.find(b"\x85\xeb\x91\x3f")
-            elif save_version >= 25.02:
-                marker_de = read_bytes.find(b"\xec\x51\xb8\x3f")
-            elif save_version >= 25.01:
-                marker_de = read_bytes.find(b"\x3d\x0a\xb7\x3f")
-            elif save_version >= 20.16:
-                marker_de = read_bytes.find(b"\x8f\xc2\xb5\x3f")
-            elif save_version >= 20.06:
-                marker_de = read_bytes.find(b"\xe1\x7a\xb4\x3f")
-            elif save_version >= 13.34:
-                marker_de = read_bytes.find(b"\x33\x33\xb3\x3f")
-            elif save_version >= 13.07:
-                marker_de = read_bytes.find(b"\x29\x5c\xaf\x3f")
-            else:
-                marker_de = read_bytes.find(b"\x7b\x14\xae\x3f")
-            new_marker = -1
-            if marker_up > 0 and marker_de < 0 and marker_hd < 0: # aok marker can appear in up
-                new_marker = marker_up
-            elif marker_de > 0 and marker_up < 0 and marker_aok < 0 and marker_hd < 0:
-                new_marker = marker_de
-            elif marker_aok > 0 and marker_up < 0 and marker_de < 0 and marker_hd < 0:
-                new_marker = marker_aok
-            elif marker_hd > 0 and marker_up < 0 and marker_de < 0 and marker_aok < 0:
-                new_marker = marker_hd
-            if new_marker == -1:
+            marker_de = -1
+            for sv, search in DE_MARKERS.items():
+                if save_version >= sv:
+                    marker_de = read_bytes.find(search)
+                    break
+            marker = -1
+            if marker_aok > 0 and version is Version.AOK:
+                marker = marker_aok
+            elif marker_hd > 0 and version is Version.HD:
+                marker = marker_hd
+            elif marker_de > 0 and version is Version.DE:
+                marker = marker_de
+            elif marker_up > 0:
+                marker = marker_up
+            if marker == -1:
                 raise RuntimeError("could not find scenario marker")
-            marker = new_marker
             # Backtrack through the achievements and initial structure footer
             backtrack = ((1817 * (num_players - 1)) + 4 + 19)
         # Seek to the position we found
